==> rucy-0.4.0.tar.gz: rucy-0.4.0/lib_conf/rucy/config_sys.rb <==
# $Id: config_sys.rb,v 1.4 2004/12/25 01:59:35 toki Exp $

require 'singleton'
require 'forwardable'
require 'socket'
require 'digest/md5'

module Rucy
  class LazyLoadProxy
    include Singleton
    extend Forwardable

    def initialize(mod_lib, mod_name)
      @module = nil
      @mod_lib = mod_lib
      @mod_name = mod_name
    end

    def __getobj__
      unless (@module) then
	require @mod_lib
	@module = Object.const_get(@mod_name)
      end

      @module
    end
  end

  class EtcProxy < LazyLoadProxy
    def initialize
      super('etc', :Etc)
    end

    def_delegator :__getobj__, :getpwnam
    def_delegator :__getobj__, :getgrnam
  end

  class NKFProxy < LazyLoadProxy
    def initialize
      super('nkf', :NKF)
    end

    def_delegator :__getobj__, :nkf
  end

  class UconvProxy < LazyLoadProxy
    def initialize
      super('uconv', :Uconv)
    end

    def_delegator :__getobj__, :euctou8
    def_delegator :__getobj__, :u8toeuc
    def_delegator :__getobj__, :u8tou16
  end

  module Config
    def config_sys(rep)
      rep.set_value(:Etc, EtcProxy.instance)
      rep.set_value(:NKF, NKFProxy.instance)
      rep.set_value(:Uconv, UconvProxy.instance)
      rep.set_value(:File, File)
      rep.set_value(:LogFile, File)
      rep.set_value(:STDOUT, STDOUT)
      rep.set_value(:Signal, Signal)
      rep.set_value(:Process, Process)
      rep.set_value(:Digest, Digest::MD5)
      rep.set_value(:BasicSocket, BasicSocket)
      rep.set_class(:TCPServer, TCPServer)
      rep
    end
    module_function :config_sys
  end
end

==> rucy-0.5.0.tar.gz: rucy-0.5.0/lib_conf/rucy/config_sys.rb <==
# $Id: config_sys.rb,v 1.7 2005/02/11 16:24:59 toki Exp $

require 'singleton'
require 'forwardable'
require 'socket'
require 'digest/md5'
require 'rucy/config'

module Rucy
  class LazyLoadProxy
    include Singleton
    extend Forwardable

    def initialize(mod_lib, mod_name)
      @module = nil
      @mod_lib = mod_lib
      @mod_name = mod_name
    end

    def __getobj__
      unless (@module) then
	require @mod_lib
	@module = Object.const_get(@mod_name)
      end

      @module
    end
  end

  class EtcProxy < LazyLoadProxy
    def initialize
      super('etc', :Etc)
    end

    def_delegator :__getobj__, :getpwnam
    def_delegator :__getobj__, :getgrnam
  end

  class NKFProxy < LazyLoadProxy
    def initialize
      super('nkf', :NKF)
    end

    def_delegator :__getobj__, :nkf
  end

  class UconvProxy < LazyLoadProxy
    def initialize
      super('uconv', :Uconv)
    end

    def_delegator :__getobj__, :euctou8
    def_delegator :__getobj__, :u8toeuc
    def_delegator :__getobj__, :u8tou16
  end

  module Config
    def config_sys(rep)
      rep.set_value(:Etc_module, EtcProxy.instance)
      rep.set_value(:NKF_module, NKFProxy.instance)
      rep.set_value(:Uconv_module, UconvProxy.instance)
      rep.set_value(:File_class, File)
      rep.set_value(:STDOUT, STDOUT)
      rep.set_value(:Signal_module, Signal)
      rep.set_value(:Process_module, Process)
      rep.set_value(:Digest_class, Digest::MD5)
      rep.set_value(:BasicSocket_class, BasicSocket)
      rep.set_class(:TCPServer, TCPServer)
      rep
    end
    module_function :config_sys

    setup{|rep| config_sys(rep) }
  end
end
